@@ -4,7 +4,7 @@
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.report import Report
-from trytond.backend import TableHandler
+from trytond.backend import TableHandler, FIELDS
 from decimal import Decimal
 import datetime
 import md5
@@ -33,14 +33,16 @@ class Move(ModelSQL, ModelView):
     journal = fields.Many2One('account.journal', 'Journal', required=True,
             states=_MOVE_STATES, depends=_MOVE_DEPENDS)
     date = fields.Date('Effective Date', required=True, states=_MOVE_STATES,
-            depends=_MOVE_DEPENDS)
+            depends=_MOVE_DEPENDS, on_change_with=['period', 'journal', 'date'])
     post_date = fields.Date('Post Date', readonly=True)
     state = fields.Selection([
         ('draft', 'Draft'),
         ('posted', 'Posted'),
         ], 'State', required=True, readonly=True)
     lines = fields.One2Many('account.move.line', 'move', 'Lines',
-            states=_MOVE_STATES, depends=_MOVE_DEPENDS)
+            states=_MOVE_STATES, depends=_MOVE_DEPENDS,
+            context="{'journal': journal, 'period': period, " \
+                    "'date': date}")
 
     def __init__(self):
         super(Move, self).__init__()
@@ -87,9 +89,33 @@ class Move(ModelSQL, ModelView):
         return 'draft'
 
     def default_date(self, cursor, user, context=None):
+        period_obj = self.pool.get('account.period')
         date_obj = self.pool.get('ir.date')
+        period_id = self.default_period(cursor, user, context=context)
+        if period_id:
+            period = period_obj.browse(cursor, user, period_id,
+                    context=context)
+            return period.start_date
         return date_obj.today(cursor, user, context=context)
 
+    def on_change_with_date(self, cursor, user, ids, vals,
+            context=None):
+        line_obj = self.pool.get('account.move.line')
+        period_obj = self.pool.get('account.period')
+        res = vals['date']
+        line_ids = line_obj.search(cursor, user, [
+            ('journal', '=', vals.get('journal', False)),
+            ('period', '=', vals.get('period', False)),
+            ], order=[('id', 'DESC')], limit=1, context=context)
+        if line_ids:
+            line = line_obj.browse(cursor, user, line_ids[0], context=context)
+            res = line.date
+        elif vals.get('period'):
+            period = period_obj.browse(cursor, user, vals['period'],
+                    context=context)
+            res = period.start_date
+        return res
+
     def check_centralisation(self, cursor, user, ids):
         for move in self.browse(cursor, user, ids):
             if move.journal.centralised:
@@ -416,7 +442,7 @@ class Line(ModelSQL, ModelView):
             domain=[('kind', '!=', 'view')],
             select=1,
             on_change=['account', 'debit', 'credit', 'tax_lines',
-                'journal', 'move', 'account_kind'])
+                'journal', 'move'])
     move = fields.Many2One('account.move', 'Move', states=_LINE_STATES,
             select=1, required=True)
     journal = fields.Function('get_move_field', fnct_inv='set_move_field',
@@ -439,8 +465,6 @@ class Line(ModelSQL, ModelView):
             on_change=['move', 'party', 'account', 'debit', 'credit',
                 'journal'], select=1, depends=['debit', 'credit', 'account',
                     'journal'])
-    blocked = fields.Boolean('Litigation',
-            help='Mark the line as litigation with the party.')
     maturity_date = fields.Date('Maturity Date',
             help='This field is used for payable and receivable lines. \n' \
                     'You can put the limit date for the payment.')
@@ -461,15 +485,6 @@ class Line(ModelSQL, ModelView):
             string='Currency Digits')
     second_currency_digits = fields.Function('get_currency_digits',
             type='integer', string='Second Currency Digits')
-    account_kind = fields.Function('get_account_kind', type='selection',
-            string='Account Kind', selection=[
-                ('other', 'Other'),
-                ('payable', 'Payable'),
-                ('revenue', 'Revenue'),
-                ('receivable', 'Receivable'),
-                ('expense', 'Expense'),
-                ('view', 'View'),
-                ])
 
     def __init__(self):
         super(Line, self).__init__()
@@ -496,6 +511,14 @@ class Line(ModelSQL, ModelView):
             'already_reconciled': 'Line "%s" (%d) already reconciled!',
             })
 
+    def init(self, cursor, module_name):
+        super(Line, self).init(cursor, module_name)
+
+        table = TableHandler(cursor, self, module_name)
+
+        # Migration from 1.2
+        table.not_null_action('blocked', action='remove')
+
     def default_date(self, cursor, user, context=None):
         '''
         Return the date of the last line for journal, period
@@ -508,26 +531,24 @@ class Line(ModelSQL, ModelView):
         if context is None:
             context = {}
         res = date_obj.today(cursor, user, context=context)
-        if context.get('journal') and context.get('period'):
-            line_ids = self.search(cursor, user, [
-                ('journal', '=', context['journal']),
-                ('period', '=', context['period']),
-                ], order=[('id', 'DESC')], limit=1, context=context)
-            if line_ids:
-                line = self.browse(cursor, user, line_ids[0], context=context)
-                res = line.date
-            else:
-                period = period_obj.browse(cursor, user, context['period'],
-                        context=context)
-                res = period.start_date
+        line_ids = self.search(cursor, user, [
+            ('journal', '=', context.get('journal', False)),
+            ('period', '=', context.get('period', False)),
+            ], order=[('id', 'DESC')], limit=1, context=context)
+        if line_ids:
+            line = self.browse(cursor, user, line_ids[0], context=context)
+            res = line.date
+        elif context.get('period'):
+            period = period_obj.browse(cursor, user, context['period'],
+                    context=context)
+            res = period.start_date
+        if context.get('date'):
+            res = context['date']
         return res
 
     def default_state(self, cursor, user, context=None):
         return 'draft'
 
-    def default_blocked(self, cursor, user, context=None):
-        return False
-
     def default_active(self, cursor, user, context=None):
         return True
 
@@ -694,12 +715,6 @@ class Line(ModelSQL, ModelView):
                         res[name][line.id] = line.account.second_currency.digits
         return res
 
-    def get_account_kind(self, cursor, user, ids, name, arg, context=None):
-        res = {}
-        for line in self.browse(cursor, user, ids, context=context):
-            res[line.id] = line.account.kind
-        return res
-
     def on_change_debit(self, cursor, user, ids, vals, context=None):
         res = {}
         if context is None:
@@ -753,14 +768,12 @@ class Line(ModelSQL, ModelView):
                 if not res['tax_lines']:
                     del res['tax_lines']
 
-        res['account_kind'] = 'other'
         if vals.get('account'):
             account = account_obj.browse(cursor, user, vals['account'],
                     context=context)
             res['currency_digits'] = account.currency_digits
             if account.second_currency:
                 res['second_currency_digits'] = account.second_currency.digits
-            res['account_kind'] = account.kind
         return res
 
     def _compute_tax_lines(self, cursor, user, ids, vals, journal_type,
@@ -827,16 +840,20 @@ class Line(ModelSQL, ModelView):
             return res
 
         if party and (not vals.get('debit')) and (not vals.get('credit')):
+            type_name = FIELDS[self.debit._type].sql_type(self.debit)[0]
             query = 'SELECT ' \
-                        'COALESCE(SUM(' \
+                        'CAST(COALESCE(SUM(' \
                             '(COALESCE(debit, 0) - COALESCE(credit, 0))' \
-                        '), 0)::NUMERIC ' \
+                        '), 0) AS ' + type_name + ') ' \
                     'FROM account_move_line ' \
                     'WHERE reconciliation IS NULL ' \
                         'AND party = %s ' \
                         'AND account = %s'
             cursor.execute(query, (party.id, party.account_receivable.id))
             amount = cursor.fetchone()[0]
+            # SQLite uses float for SUM
+            if not isinstance(amount, Decimal):
+                amount = Decimal(str(amount))
             if not currency_obj.is_zero(cursor, user,
                     party.account_receivable.currency, amount):
                 if amount > Decimal('0.0'):
@@ -989,13 +1006,13 @@ class Line(ModelSQL, ModelView):
             fiscalyear_ids = fiscalyear_obj.search(cursor, user, [
                 ('state', '=', 'open'),
                 ], context=context)
-            fiscalyear_clause = (','.join([str(x) for x in fiscalyear_ids])) or '0'
+            fiscalyear_clause = (','.join(map(str, fiscalyear_ids))) or '0'
         else:
             fiscalyear_ids = [int(context.get('fiscalyear'))]
             fiscalyear_clause = '%s' % int(context.get('fiscalyear'))
 
         if context.get('periods', False):
-            ids = ','.join([str(int(x)) for x in context['periods']])
+            ids = ','.join(str(int(x)) for x in context['periods'])
             if context.get('posted'):
                 return (obj + '.active ' \
                         'AND ' + obj + '.state != \'draft\' ' \
@@ -1331,9 +1348,8 @@ class OpenJournalAsk(ModelView):
     _description = __doc__
     journal = fields.Many2One('account.journal', 'Journal', required=True)
     period = fields.Many2One('account.period', 'Period', required=True,
-            domain="[('state', '!=', 'close'), " \
-                    "('fiscalyear.company.id', '=', " \
-                        "context.get('company', False))]")
+            domain=[('state', '!=', 'close'),
+                "('fiscalyear.company.id', '=', context.get('company', False))"])
 
     def default_period(self, cursor, user, context=None):
         period_obj = self.pool.get('account.period')
