@@ -181,7 +181,7 @@ class Party(ModelSQL, ModelView):
                 'HAVING ' + \
                     'AND'.join('(SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))) ' \
                         + ' ' + x[1] + ' %s) ' for x in args),
-                    [code] + today_value + [company_id] + [x[2] for x in args])
+                    [code] + today_value + [company_id] + [Decimal(x[2]) for x in args])
         return [('id', 'in', [x[0] for x in cursor.fetchall()])]
 
 Party()
